##  Overview
The LeanIX platform offers a predefined, fully configurable Meta Model that can be configured to the needs of the customer. Mostly, customers benefit from the out-of-the-box best practices, but often it's important to understand the options to adapt the model once maturity is growing.
![Video thumbnail](https://cdnapisec.kaltura.com/html5/html5lib/v2.101/modules/KalturaSupport/thumbnail.php/p/1921661/uiconf_id/37285991/entry_id/1_lyy551il/height/480?&flashvars\[parentDomain\]=https%3A%2F%2Fhelp.sap.com%2Fdocs%2Fleanix%2Fea%2Fmeta-model-v3%3Fversion%3DCLOUD)
